
package aazaaa.util;

import javax.faces.model.DataModel;

public abstract class PaginationHelper {

    private int pageSize;
    private int page;
    private int selectedItem = -1;

    public PaginationHelper(int pageSize, int selectedItemIndex) {
        this.pageSize = pageSize;
        if (selectedItemIndex != -1) {
            page = selectedItemIndex / pageSize;
            selectedItem = selectedItemIndex % pageSize;
        }
    }

    public abstract int getItemsCount();

    protected abstract DataModel createPageDataModel();
    
    public final DataModel createItems() {
        DataModel model = createPageDataModel();
        if (selectedItem != -1) {
            model.setRowIndex(selectedItem);
        }
        return model;
    }

    public int getPageFirstItem() {
        return page*pageSize;
    }

    public int getPageLastItem() {
        int i = getPageFirstItem() + pageSize -1;
        int count = getItemsCount() - 1;
        if (i > count) {
            i = count;
        }
        if (i < 0) {
            i = 0;
        }
        return i;
    }

    public boolean isHasNextPage() {
        return (page+1)*pageSize+1 <= getItemsCount();
    }

    public void nextPage() {
        if (isHasNextPage()) {
            page++;
        }
    }

    public boolean isHasPreviousPage() {
        return page > 0;
    }

    public void previousPage() {
        if (isHasPreviousPage()) {
            page--;
        }
    }

    public int getPageSize() {
        return pageSize;
    }

}
